"use strict";

SHINKEN_LIST.PaginationFromData = function ( type ) {
    this.__class_name__ = "SHINKEN_LIST.PaginationFromData";
    this.type           = type;
    this.initSpecific();
};

SHINKEN_LIST.PaginationFromData.prototype = {
    initSpecific: function () {
        this.init();
    },
    
    //********************************************  HTML  *****************************************************//
    computeHtml: function () {
        this.dom_element = DOM.Service.createElement( "tr", { class: "shinken-filter-line" } );
        for ( var i = 0, _size_i = this.contents.length; i < _size_i; i++ ) {
            this.contents[ i ].computeHtml();
            DOM.Service.addElementTo( this.contents[ i ].getDomElement(), this.dom_element );
        }
    }
    
    
    
};

SHINKEN.TOOLS.CLASS.addPrototype( SHINKEN_LIST.PaginationFromData, SHINKEN_LIST.Pagination );